summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorStephen Smalley <sds@tycho.nsa.gov>2013-04-12 14:49:38 -0400
committerRicardo Cerqueira <cyanogenmod@cerqueira.org>2013-07-18 21:03:12 +0100
commit21a5771c0ec015a4bfb77cc110bdbc0bb4848bcf (patch)
tree4f002003733e6eb5197b0f23f7c897a8733c4173
parent1c6f7a8d7b69a2ac5d830b471db4941f2eed8192 (diff)
downloadframeworks_base-21a5771c0ec015a4bfb77cc110bdbc0bb4848bcf.zip
frameworks_base-21a5771c0ec015a4bfb77cc110bdbc0bb4848bcf.tar.gz
frameworks_base-21a5771c0ec015a4bfb77cc110bdbc0bb4848bcf.tar.bz2
Replace SEAndroid with SELinux.
Change-Id: Ibbe544a9f025d71ad416bc01cee2145b62d7b2d4 Signed-off-by: Stephen Smalley <sds@tycho.nsa.gov>
-rw-r--r--core/java/android/os/Process.java4
-rw-r--r--core/java/com/android/internal/os/ZygoteConnection.java6
2 files changed, 5 insertions, 5 deletions
diff --git a/core/java/android/os/Process.java b/core/java/android/os/Process.java
index 05099fb..3cb361f9 100644
--- a/core/java/android/os/Process.java
+++ b/core/java/android/os/Process.java
@@ -379,7 +379,7 @@ public class Process {
* @param gids Additional group-ids associated with the process.
* @param debugFlags Additional flags.
* @param targetSdkVersion The target SDK version for the app.
- * @param seInfo null-ok SE Android information for the new process.
+ * @param seInfo null-ok SELinux information for the new process.
* @param zygoteArgs Additional arguments to supply to the zygote process.
*
* @return An object that describes the result of the attempt to start the process.
@@ -559,7 +559,7 @@ public class Process {
* new process should setgroup() to.
* @param debugFlags Additional flags.
* @param targetSdkVersion The target SDK version for the app.
- * @param seInfo null-ok SE Android information for the new process.
+ * @param seInfo null-ok SELinux information for the new process.
* @param extraArgs Additional arguments to supply to the zygote process.
* @return An object that describes the result of the attempt to start the process.
* @throws ZygoteStartFailedEx if process start failed for any reason
diff --git a/core/java/com/android/internal/os/ZygoteConnection.java b/core/java/com/android/internal/os/ZygoteConnection.java
index d24513a..e7447af 100644
--- a/core/java/com/android/internal/os/ZygoteConnection.java
+++ b/core/java/com/android/internal/os/ZygoteConnection.java
@@ -825,7 +825,7 @@ class ZygoteConnection {
}
/**
* Applies zygote security policy for SEAndroid information.
*
* @param args non-null; zygote spawner arguments
* @param peer non-null; peer credentials
@@ -844,7 +844,7 @@ class ZygoteConnection {
if (!(peerUid == 0 || peerUid == Process.SYSTEM_UID)) {
// All peers with UID other than root or SYSTEM_UID
throw new ZygoteSecurityException(
- "This UID may not specify SEAndroid info.");
+ "This UID may not specify SELinux info.");
}
boolean allowed = SELinux.checkSELinuxAccess(peerSecurityContext,
@@ -853,7 +853,7 @@ class ZygoteConnection {
"specifyseinfo");
if (!allowed) {
throw new ZygoteSecurityException(
- "Peer may not specify SEAndroid info");
+ "Peer may not specify SELinux info");
}
return;
@@ -825,7 +825,7 @@ class ZygoteConnection {
}
/**
- * Applies zygote security policy for SEAndroid information.
+ * Applies zygote security policy for SELinux information.
*
* @param args non-null; zygote spawner arguments